==> rong-ui-react-0.0.1.tgz: package/es/select-date/select-date.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } Object.defineProperty(subClass, "prototype", { value: Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }), writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import AsyncValidator from 'async-validator';
import memoize from "memoize-one";
import DatePicker from '../date-picker';
import { setDefaultProps, classNames } from '../_util/assist';
import { Consumer } from '../form/formContext';
import './style/select-date.less';
var prefixCls = 'r-selectdate';

var SelectDate = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(SelectDate, _React$PureComponent);

  var _super = _createSuper(SelectDate);

  function SelectDate(props) {
    var _this;

    _classCallCheck(this, SelectDate);

    _this = _super.call(this, props);

    _defineProperty(_assertThisInitialized(_this), "getIsRequired", memoize(function (required) {
      if (required === false) {
        return false;
      }

      return _this.fieldRules.some(function (item) {
        return item.required === true;
      });
    }));

    _defineProperty(_assertThisInitialized(_this), "getShowErrorMsg", memoize(function (validateState) {
      return validateState === 'error' && (_this.form ? _this.form.props.showMessage && _this.props.showMessage : _this.props.showMessage);
    }));

    _defineProperty(_assertThisInitialized(_this), "onConfirm", function (date) {
      _this.setValue(date.value, function () {}, {
        from: 'select'
      });
    });

    _this.state = {
      value: props.value,
      prePropsValue: props.value,
      validateState: '',
      validateMessage: ''
    }; // 不需要驱动视图更新的数据放这里

    _this._state = {
      initialValue: '',
      isMounted: false
    };
    _this.selectWrapRef = /*#__PURE__*/React.createRef();
    return _this;
  }

  _createClass(SelectDate, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      return /*#__PURE__*/React.createElement(Consumer, null, function (context) {
        _this2.form = context;
        console.log('SelectDate mounted or updated');
        var _this2$props = _this2.props,
            title = _this2$props.title,
            prepend = _this2$props.prepend,
            append = _this2$props.append;
        var validateMessage = _this2.state.validateMessage;
        return /*#__PURE__*/React.createElement("div", {
          className: _this2.wrapCls,
          ref: _this2.selectWrapRef
        }, /*#__PURE__*/React.createElement("div", {
          className: _this2.innerCls
        }, /*#__PURE__*/React.createElement("label", {
          className: _this2.labelCls,
          style: _this2.labelStyle
        }, title), prepend && /*#__PURE__*/React.createElement("div", {
          className: _this2.prependCls
        }, prepend), /*#__PURE__*/React.createElement("div", {
          className: _this2.contentCls
        }, /*#__PURE__*/React.createElement(DatePicker, _extends({}, _this2.props, {
          className: _this2.selectCls,
          onConfirm: _this2.onConfirm
        }))), append && /*#__PURE__*/React.createElement("div", {
          className: _this2.appendCls
        }, append), /*#__PURE__*/React.createElement("div", {
          className: _this2.arrowCls
        }, /*#__PURE__*/React.createElement("svg", {
          width: "6px",
          height: "10px",
          style: _this2.arrowStyle,
          viewBox: "0 0 6 10",
          version: "1.1",
          xmlns: "http://www.w3.org/2000/svg",
          xmlnsXlink: "http://www.w3.org/1999/xlink"
        }, /*#__PURE__*/React.createElement("g", {
          stroke: "none",
          strokeWidth: "1",
          fill: "none",
          fillRule: "evenodd"
        }, /*#__PURE__*/React.createElement("g", {
          transform: "translate(-350.000000, -20.000000)",
          fill: _this2.arrowStyle.color || '#C8C7CC'
        }, /*#__PURE__*/React.createElement("g", null, /*#__PURE__*/React.createElement("g", {
          transform: "translate(346.000000, 18.000000)"
        }, /*#__PURE__*/React.createElement("g", {
          transform: "translate(7.000000, 7.000000) rotate(-270.000000) translate(-7.000000, -7.000000) translate(2.750000, 4.500000)"
        }, /*#__PURE__*/React.createElement("path", {
          d: "M6.53188022,3.0259328 L3.02129527,6.5321515 C2.73046889,6.82261617 2.25894616,6.82261617 1.96811978,6.5321515 C1.67729341,6.24168683 1.67729341,5.77075056 1.96811978,5.48028589 L4.95211699,2.5 L1.96811978,-0.480285891 C1.67729341,-0.770750558 1.67729341,-1.24168683 1.96811978,-1.5321515 C2.25894616,-1.82261617 2.73046889,-1.82261617 3.02129527,-1.5321515 L6.53188022,1.9740672 C6.82270659,2.26453186 6.82270659,2.73546814 6.53188022,3.0259328 Z",
          fillRule: "nonzero",
          transform: "translate(4.250000, 2.500000) rotate(-90.000000) translate(-4.250000, -2.500000) "
        }))))))))), _this2.showErrorMsg && /*#__PURE__*/React.createElement("div", {
          className: _this2.errorCls
        }, validateMessage));
      });
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      this.form && this.form._state.fields.push(this);
      this._state.initialValue = this.state.value;
      this._state.isMounted = true;
      this.$el = this.selectWrapRef.current;
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.form && this.form._state.fields.splice(this.form._state.fields.indexOf(this), 1);
      this._state.isMounted = false;
    }
  }, {
    key: "wrapCls",
    get: function get() {
      var _ref;

      var value = this.state.value;
      var _this$props = this.props,
          labelPosition = _this$props.labelPosition,
          textPosition = _this$props.textPosition,
          mode = _this$props.mode,
          className = _this$props.className,
          readonly = _this$props.readonly,
          disabled = _this$props.disabled;

      var _labelPosition = labelPosition || this.form && this.form.props.labelPosition || 'left';

      var _textPosition = textPosition || this.form && this.form.props.textPosition || 'left';

      var _mode = mode || this.form && this.form.props.mode || 'default';

      return classNames([this.form && 'form-item', prefixCls, "".concat(prefixCls, "-label-").concat(_labelPosition), "".concat(prefixCls, "-text-").concat(_textPosition), "".concat(prefixCls, "-mode-").concat(_mode), className, (_ref = {}, _defineProperty(_ref, "".concat(prefixCls, "-empty"), value === ''), _defineProperty(_ref, "".concat(prefixCls, "-error"), this.showErrorMsg), _defineProperty(_ref, "".concat(prefixCls, "-required"), this.isRequired), _defineProperty(_ref, "".concat(prefixCls, "-readonly"), !!readonly), _defineProperty(_ref, "".concat(prefixCls, "-disabled"), !!disabled), _defineProperty(_ref, "".concat(prefixCls, "-placeholder"), value === ''), _ref)]);
    }
  }, {
    key: "innerCls",
    get: function get() {
      return "".concat(prefixCls, "-inner");
    }
  }, {
    key: "labelCls",
    get: function get() {
      return "".concat(prefixCls, "-label");
    }
  }, {
    key: "labelStyle",
    get: function get() {
      var style = {};

      if (this.props.labelWidth || this.props.labelWidth === 0) {
        style.width = this.props.labelWidth;
      } else if (this.form && (this.form.props.labelWidth || this.form.props.labelWidth === 0)) {
        style.width = this.form.props.labelWidth;
      }

      return style;
    }
  }, {
    key: "prependCls",
    get: function get() {
      return "".concat(prefixCls, "-prepend");
    }
  }, {
    key: "appendCls",
    get: function get() {
      return "".concat(prefixCls, "-append");
    }
  }, {
    key: "arrowStyle",
    get: function get() {
      var style = {
        color: '#666',
        width: '0.32rem'
      };
      return this.props.selectArrowStyle || this.form && this.form.props.selectArrowStyle || style;
    }
  }, {
    key: "contentCls",
    get: function get() {
      return "".concat(prefixCls, "-content");
    }
  }, {
    key: "selectCls",
    get: function get() {
      return "".concat(prefixCls, "-select");
    }
  }, {
    key: "arrowCls",
    get: function get() {
      return "".concat(prefixCls, "-arrow-right");
    }
  }, {
    key: "errorCls",
    get: function get() {
      return "".concat(prefixCls, "-error-tip");
    }
  }, {
    key: "fieldRules",
    get: function get() {
      var _this$props2 = this.props,
          title = _this$props2.title,
          rules = _this$props2.rules;
      var defaultRules = [{
        required: true,
        message: "".concat(title, "\u4E0D\u80FD\u4E3A\u7A7A")
      }];
      return [].concat(rules ? rules : defaultRules);
    } // isRequired

  }, {
    key: "isRequired",
    get: function get() {
      return this.getIsRequired(this.props.required);
    }
  }, {
    key: "showErrorMsg",
    get: // showErrorMsg
    function get() {
      return this.getShowErrorMsg(this.state.validateState);
    }
  }, {
    key: "getFilterRules",
    value: function getFilterRules(trigger) {
      return this.fieldRules.filter(function (rule) {
        return !rule.trigger || rule.trigger.indexOf(trigger) !== -1;
      });
    }
  }, {
    key: "validate",
    value: function validate(trigger) {
      var _this3 = this;

      var callback = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : function () {};
      var value = this.state.value;
      var initialValue = this._state.initialValue;
      var _this$props3 = this.props,
          name = _this$props3.name,
          title = _this$props3.title;
      var rules = this.getFilterRules(trigger);
      var isInitialValue = this.isRequired && value !== '' && initialValue === value;

      if (!this.isRequired || isInitialValue) {
        callback();
        return true;
      }

      var prop = name || title || 'prop';
      var descriptor = {};
      descriptor[prop] = rules;
      var validator = new AsyncValidator(descriptor);
      var model = {};
      model[prop] = value;
      validator.validate(model, {
        first: true,
        suppressWarning: true,
        component: this
      }).then(function () {
        _this3.setState({
          validateState: 'success',
          validateMessage: ''
        });

        callback('');
      }).catch(function (_ref2) {
        var errors = _ref2.errors,
            fields = _ref2.fields;
        var errMsg = errors[0].message || '';

        _this3.setState({
          validateState: 'error',
          validateMessage: errMsg
        });

        callback(errMsg);
      });
    }
  }, {
    key: "resetField",
    value: function resetField() {
      this.setState({
        validateState: '',
        validateMessage: ''
      });
      this.setValue(this._state.initialValue, null, {
        from: 'reset'
      });
    }
    /* 获取表单数据 */

  }, {
    key: "getValue",
    value: function getValue() {
      return {
        name: this.props.name,
        value: this.state.value
      };
    }
  }, {
    key: "setValue",
    value: function setValue(value, callback) {
      var _this4 = this;

      var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      var opts = Object.assign({
        event: null,
        component: this,
        value: value
      }, options);
      var from = options.from;
      this._state.isMounted && this.setState({
        value: value
      }, function () {
        _this4.props.onChange(opts);

        _this4.form && _this4.form.onChange(opts);
        callback && callback.call(_this4);

        if (from === 'select') {
          _this4.validate('select');
        }
      });
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(nextProps, prevState) {
      if (nextProps.value !== prevState.prePropsValue) {
        return {
          value: nextProps.value,
          prePropsValue: nextProps.value
        };
      }

      return null;
    }
  }]);

  return SelectDate;
}(React.PureComponent);

setDefaultProps(SelectDate, {
  title: {
    type: PropTypes.string
  },
  value: {
    type: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    default: ''
  },
  placeholder: {
    type: PropTypes.string,
    default: ''
  },
  disabled: {
    type: PropTypes.oneOf(['disabled', 1, 0, true, false])
  },
  readonly: {
    type: PropTypes.oneOf(['readonly', 1, 0, true, false])
  },
  labelPosition: {
    type: PropTypes.oneOf(['left', 'right', 'top'])
  },
  labelWidth: {
    type: PropTypes.string
  },
  textPosition: {
    type: PropTypes.oneOf(['left', 'center', 'right'])
  },
  // 是否显示校验错误信息
  showMessage: {
    type: PropTypes.bool,
    default: true
  },
  // 校验规则
  rules: {
    type: PropTypes.array
  },
  required: {
    type: PropTypes.bool
  },
  onChange: {
    type: PropTypes.func,
    default: function _default() {}
  },
  pickerTitle: {
    type: PropTypes.string
  },
  cancelBtnText: {
    type: PropTypes.string
  },
  confirmBtnText: {
    type: PropTypes.string
  },
  selectArrowStyle: {
    type: PropTypes.object
  },
  mode: {
    type: PropTypes.string
  }
});
export default SelectDate;

==> rong-ui-react-0.0.3.tgz: package/es/select-date/select-date.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

import React from 'react';
import PropTypes from 'prop-types';
import AsyncValidator from 'async-validator';
import memoize from "memoize-one";
import DatePicker from '../date-picker';
import { setDefaultProps, classNames } from '../_util/assist';
import { Consumer } from '../form/formContext';
var prefixCls = 'r-selectdate';

var SelectDate = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(SelectDate, _React$PureComponent);

  var _super = _createSuper(SelectDate);

  function SelectDate(props) {
    var _this;

    _classCallCheck(this, SelectDate);

    _this = _super.call(this, props);
    _this.getIsRequired = memoize(function (required) {
      if (required === false) {
        return false;
      }

      return _this.fieldRules.some(function (item) {
        return item.required === true;
      });
    });
    _this.getShowErrorMsg = memoize(function (validateState) {
      return validateState === 'error' && (_this.form ? _this.form.props.showMessage && _this.props.showMessage : _this.props.showMessage);
    });

    _this.onConfirm = function (date) {
      _this.setValue(date.value, function () {}, {
        from: 'select'
      });
    };

    _this.state = {
      value: props.value,
      prePropsValue: props.value,
      validateState: '',
      validateMessage: ''
    }; // 不需要驱动视图更新的数据放这里

    _this._state = {
      initialValue: '',
      isMounted: false
    };
    _this.selectWrapRef = /*#__PURE__*/React.createRef();
    return _this;
  }

  _createClass(SelectDate, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      return /*#__PURE__*/React.createElement(Consumer, null, function (context) {
        _this2.form = context;
        console.log('SelectDate mounted or updated');
        var _this2$props = _this2.props,
            title = _this2$props.title,
            prepend = _this2$props.prepend,
            append = _this2$props.append;
        var validateMessage = _this2.state.validateMessage;
        return /*#__PURE__*/React.createElement("div", {
          className: _this2.wrapCls,
          ref: _this2.selectWrapRef
        }, /*#__PURE__*/React.createElement("div", {
          className: _this2.innerCls
        }, /*#__PURE__*/React.createElement("label", {
          className: _this2.labelCls,
          style: _this2.labelStyle
        }, title), prepend && /*#__PURE__*/React.createElement("div", {
          className: _this2.prependCls
        }, prepend), /*#__PURE__*/React.createElement("div", {
          className: _this2.contentCls
        }, /*#__PURE__*/React.createElement(DatePicker, _extends({}, _this2.props, {
          className: _this2.selectCls,
          onConfirm: _this2.onConfirm
        }))), append && /*#__PURE__*/React.createElement("div", {
          className: _this2.appendCls
        }, append), /*#__PURE__*/React.createElement("div", {
          className: _this2.arrowCls
        }, /*#__PURE__*/React.createElement("svg", {
          width: "6px",
          height: "10px",
          style: _this2.arrowStyle,
          viewBox: "0 0 6 10",
          version: "1.1",
          xmlns: "http://www.w3.org/2000/svg",
          xmlnsXlink: "http://www.w3.org/1999/xlink"
        }, /*#__PURE__*/React.createElement("g", {
          stroke: "none",
          strokeWidth: "1",
          fill: "none",
          fillRule: "evenodd"
        }, /*#__PURE__*/React.createElement("g", {
          transform: "translate(-350.000000, -20.000000)",
          fill: _this2.arrowStyle.color || '#C8C7CC'
        }, /*#__PURE__*/React.createElement("g", null, /*#__PURE__*/React.createElement("g", {
          transform: "translate(346.000000, 18.000000)"
        }, /*#__PURE__*/React.createElement("g", {
          transform: "translate(7.000000, 7.000000) rotate(-270.000000) translate(-7.000000, -7.000000) translate(2.750000, 4.500000)"
        }, /*#__PURE__*/React.createElement("path", {
          d: "M6.53188022,3.0259328 L3.02129527,6.5321515 C2.73046889,6.82261617 2.25894616,6.82261617 1.96811978,6.5321515 C1.67729341,6.24168683 1.67729341,5.77075056 1.96811978,5.48028589 L4.95211699,2.5 L1.96811978,-0.480285891 C1.67729341,-0.770750558 1.67729341,-1.24168683 1.96811978,-1.5321515 C2.25894616,-1.82261617 2.73046889,-1.82261617 3.02129527,-1.5321515 L6.53188022,1.9740672 C6.82270659,2.26453186 6.82270659,2.73546814 6.53188022,3.0259328 Z",
          fillRule: "nonzero",
          transform: "translate(4.250000, 2.500000) rotate(-90.000000) translate(-4.250000, -2.500000) "
        }))))))))), _this2.showErrorMsg && /*#__PURE__*/React.createElement("div", {
          className: _this2.errorCls
        }, validateMessage));
      });
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      this.form && this.form._state.fields.push(this);
      this._state.initialValue = this.state.value;
      this._state.isMounted = true;
      this.$el = this.selectWrapRef.current;
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.form && this.form._state.fields.splice(this.form._state.fields.indexOf(this), 1);
      this._state.isMounted = false;
    }
  }, {
    key: "wrapCls",
    get: function get() {
      var _ref;

      var value = this.state.value;
      var _this$props = this.props,
          labelPosition = _this$props.labelPosition,
          textPosition = _this$props.textPosition,
          mode = _this$props.mode,
          className = _this$props.className,
          readonly = _this$props.readonly,
          disabled = _this$props.disabled;

      var _labelPosition = labelPosition || this.form && this.form.props.labelPosition || 'left';

      var _textPosition = textPosition || this.form && this.form.props.textPosition || 'left';

      var _mode = mode || this.form && this.form.props.mode || 'default';

      return classNames([this.form && 'form-item', prefixCls, "".concat(prefixCls, "-label-").concat(_labelPosition), "".concat(prefixCls, "-text-").concat(_textPosition), "".concat(prefixCls, "-mode-").concat(_mode), className, (_ref = {}, _defineProperty(_ref, "".concat(prefixCls, "-empty"), value === ''), _defineProperty(_ref, "".concat(prefixCls, "-error"), this.showErrorMsg), _defineProperty(_ref, "".concat(prefixCls, "-required"), this.isRequired), _defineProperty(_ref, "".concat(prefixCls, "-readonly"), !!readonly), _defineProperty(_ref, "".concat(prefixCls, "-disabled"), !!disabled), _defineProperty(_ref, "".concat(prefixCls, "-placeholder"), value === ''), _ref)]);
    }
  }, {
    key: "innerCls",
    get: function get() {
      return "".concat(prefixCls, "-inner");
    }
  }, {
    key: "labelCls",
    get: function get() {
      return "".concat(prefixCls, "-label");
    }
  }, {
    key: "labelStyle",
    get: function get() {
      var style = {};

      if (this.props.labelWidth || this.props.labelWidth === 0) {
        style.width = this.props.labelWidth;
      } else if (this.form && (this.form.props.labelWidth || this.form.props.labelWidth === 0)) {
        style.width = this.form.props.labelWidth;
      }

      return style;
    }
  }, {
    key: "prependCls",
    get: function get() {
      return "".concat(prefixCls, "-prepend");
    }
  }, {
    key: "appendCls",
    get: function get() {
      return "".concat(prefixCls, "-append");
    }
  }, {
    key: "arrowStyle",
    get: function get() {
      var style = {
        color: '#666',
        width: '0.32rem'
      };
      return this.props.selectArrowStyle || this.form && this.form.props.selectArrowStyle || style;
    }
  }, {
    key: "contentCls",
    get: function get() {
      return "".concat(prefixCls, "-content");
    }
  }, {
    key: "selectCls",
    get: function get() {
      return "".concat(prefixCls, "-select");
    }
  }, {
    key: "arrowCls",
    get: function get() {
      return "".concat(prefixCls, "-arrow-right");
    }
  }, {
    key: "errorCls",
    get: function get() {
      return "".concat(prefixCls, "-error-tip");
    }
  }, {
    key: "fieldRules",
    get: function get() {
      var _this$props2 = this.props,
          title = _this$props2.title,
          rules = _this$props2.rules;
      var defaultRules = [{
        required: true,
        message: "".concat(title, "\u4E0D\u80FD\u4E3A\u7A7A")
      }];
      return [].concat(rules ? rules : defaultRules);
    } // isRequired

  }, {
    key: "isRequired",
    get: function get() {
      return this.getIsRequired(this.props.required);
    }
  }, {
    key: "showErrorMsg",
    get: // showErrorMsg
    function get() {
      return this.getShowErrorMsg(this.state.validateState);
    }
  }, {
    key: "getFilterRules",
    value: function getFilterRules(trigger) {
      return this.fieldRules.filter(function (rule) {
        return !rule.trigger || rule.trigger.indexOf(trigger) !== -1;
      });
    }
  }, {
    key: "validate",
    value: function validate(trigger) {
      var _this3 = this;

      var callback = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : function () {};
      var value = this.state.value;
      var initialValue = this._state.initialValue;
      var _this$props3 = this.props,
          name = _this$props3.name,
          title = _this$props3.title;
      var rules = this.getFilterRules(trigger);
      var isInitialValue = this.isRequired && value !== '' && initialValue === value;

      if (!this.isRequired || isInitialValue) {
        callback();
        return true;
      }

      var prop = name || title || 'prop';
      var descriptor = {};
      descriptor[prop] = rules;
      var validator = new AsyncValidator(descriptor);
      var model = {};
      model[prop] = value;
      validator.validate(model, {
        first: true,
        suppressWarning: true,
        component: this
      }).then(function () {
        _this3.setState({
          validateState: 'success',
          validateMessage: ''
        });

        callback('');
      }).catch(function (_ref2) {
        var errors = _ref2.errors,
            fields = _ref2.fields;
        var errMsg = errors[0].message || '';

        _this3.setState({
          validateState: 'error',
          validateMessage: errMsg
        });

        callback(errMsg);
      });
    }
  }, {
    key: "resetField",
    value: function resetField() {
      this.setState({
        validateState: '',
        validateMessage: ''
      });
      this.setValue(this._state.initialValue, null, {
        from: 'reset'
      });
    }
    /* 获取表单数据 */

  }, {
    key: "getValue",
    value: function getValue() {
      return {
        name: this.props.name,
        value: this.state.value
      };
    }
  }, {
    key: "setValue",
    value: function setValue(value, callback) {
      var _this4 = this;

      var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      var opts = Object.assign({
        event: null,
        component: this,
        value: value
      }, options);
      var from = options.from;
      this._state.isMounted && this.setState({
        value: value
      }, function () {
        _this4.props.onChange(opts);

        _this4.form && _this4.form.onChange(opts);
        callback && callback.call(_this4);

        if (from === 'select') {
          _this4.validate('select');
        }
      });
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(nextProps, prevState) {
      if (nextProps.value !== prevState.prePropsValue) {
        return {
          value: nextProps.value,
          prePropsValue: nextProps.value
        };
      }

      return null;
    }
  }]);

  return SelectDate;
}(React.PureComponent);

setDefaultProps(SelectDate, {
  title: {
    type: PropTypes.string
  },
  value: {
    type: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    default: ''
  },
  placeholder: {
    type: PropTypes.string,
    default: ''
  },
  disabled: {
    type: PropTypes.oneOf(['disabled', 1, 0, true, false])
  },
  readonly: {
    type: PropTypes.oneOf(['readonly', 1, 0, true, false])
  },
  labelPosition: {
    type: PropTypes.oneOf(['left', 'right', 'top'])
  },
  labelWidth: {
    type: PropTypes.string
  },
  textPosition: {
    type: PropTypes.oneOf(['left', 'center', 'right'])
  },
  // 是否显示校验错误信息
  showMessage: {
    type: PropTypes.bool,
    default: true
  },
  // 校验规则
  rules: {
    type: PropTypes.array
  },
  required: {
    type: PropTypes.bool
  },
  onChange: {
    type: PropTypes.func,
    default: function _default() {}
  },
  pickerTitle: {
    type: PropTypes.string
  },
  cancelBtnText: {
    type: PropTypes.string
  },
  confirmBtnText: {
    type: PropTypes.string
  },
  selectArrowStyle: {
    type: PropTypes.object
  },
  mode: {
    type: PropTypes.string
  }
});
export default SelectDate;
